/*
 * display.h
 *
 *  Created on: 7  2024 .
 *      Author: Andrej
 */

#ifndef DISPLAY_H_
#define DISPLAY_H_

#include "gpio.h"
#include "delay.h"

/*
 * Commands[1:0]: 00 - Latch DATA
 * 				  01 - Latch Address LOW Byte
 * 				  10 - Latch Address HIGH Byte
 * 				  11 - Write DATA to Address
 */

#define STROBE_HIGH			GPIO_SetBits(GPIOB, GPIO_Pin_2);
#define STROBE_LOW			GPIO_ResetBits(GPIOB, GPIO_Pin_2);
#define CMD0_HIGH			GPIO_SetBits(GPIOB, GPIO_Pin_0);
#define CMD0_LOW			GPIO_ResetBits(GPIOB, GPIO_Pin_0);
#define CMD1_HIGH			GPIO_SetBits(GPIOB, GPIO_Pin_1);
#define CMD1_LOW			GPIO_ResetBits(GPIOB, GPIO_Pin_1);
#define CMD2_HIGH			GPIO_SetBits(GPIOB, GPIO_Pin_10);
#define CMD2_LOW			GPIO_ResetBits(GPIOB, GPIO_Pin_10);

//Commands CMD[1:0]
#define LatchDATA			{CMD0_LOW CMD1_LOW CMD2_LOW}
#define LatchLADD			{CMD0_HIGH CMD1_LOW CMD2_LOW}
#define LatchHADD			{CMD0_LOW CMD1_HIGH CMD2_LOW}
#define WriteCMD			{CMD0_HIGH CMD1_HIGH CMD2_LOW}
#define ChooseBANK			{CMD0_LOW CMD1_LOW CMD2_HIGH}

//  
#define CHAR_ADD			0x0000		//  4800     
#define ATTR_ADD			0x12C0		//   4800    () 
#define CHAR_BANK1			0x2800		//      ,    ASCII (  )
#define CHAR_BANK2	 		0x3000		//   88 (2048 )
#define CHAR_BANK3	 		0x3800		//   88 (2048 )

// 
#define WHITE				0x0
#define YELLOW				0x1
#define LGREEN				0x2
#define OLIVE				0x3
#define GREEN				0x4
#define GRAYBLUE			0x5
#define DARKBLUE			0x6
#define BLUE				0x7
#define LIGTBLUE			0x8
#define CYAN				0x9
#define VIOLET				0xA
#define RED					0xB
#define BROWN				0xC
#define BLACK				0xD
#define GRAY				0xE
#define SILVER				0xF


//Prototypes
void pulse_stb(void);
void write_byte(uint8_t vdata, uint16_t add);
void fill_display(uint8_t color);
void fill_chram(uint8_t ch);
void fill_attrs(uint8_t ink_color, uint8_t paper_color);
void fill_attr(uint8_t ink_color, uint8_t paper_color, uint16_t x, uint16_t y);
void write_char(uint8_t ch, uint16_t x, uint16_t y);
void write_string(uint8_t *ch, uint16_t x, uint16_t y);
void choose_charBank(uint8_t bank);

#endif /* DISPLAY_H_ */
